package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.DictDataMapper;
import com.zyc.system.domain.DictData;
import com.zyc.system.service.IDictDataService;

/**
 * 字典数据Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class DictDataServiceImpl implements IDictDataService 
{
    @Autowired
    private DictDataMapper dictDataMapper;

    /**
     * 查询字典数据
     * 
     * @param id 字典数据主键
     * @return 字典数据
     */
    @Override
    public DictData selectDictDataById(Integer id)
    {
        return dictDataMapper.selectDictDataById(id);
    }

    /**
     * 查询字典数据列表
     * 
     * @param dictData 字典数据
     * @return 字典数据
     */
    @Override
    public List<DictData> selectDictDataList(DictData dictData)
    {
        return dictDataMapper.selectDictDataList(dictData);
    }

    /**
     * 新增字典数据
     * 
     * @param dictData 字典数据
     * @return 结果
     */
    @Override
    public int insertDictData(DictData dictData)
    {
        return dictDataMapper.insertDictData(dictData);
    }

    /**
     * 修改字典数据
     * 
     * @param dictData 字典数据
     * @return 结果
     */
    @Override
    public int updateDictData(DictData dictData)
    {
        return dictDataMapper.updateDictData(dictData);
    }

    /**
     * 批量删除字典数据
     * 
     * @param ids 需要删除的字典数据主键
     * @return 结果
     */
    @Override
    public int deleteDictDataByIds(Integer[] ids)
    {
        return dictDataMapper.deleteDictDataByIds(ids);
    }

    /**
     * 删除字典数据信息
     * 
     * @param id 字典数据主键
     * @return 结果
     */
    @Override
    public int deleteDictDataById(Integer id)
    {
        return dictDataMapper.deleteDictDataById(id);
    }
}
